import React, { useEffect, useState } from "react";
import { useStore } from "react-redux-nano";
/**
 * The DynamicModuleLoader adds a way to register a module on mount
 * When this component is initialized, the reducer and saga from the module passed as props will be registered with the system
 * On unmount, they will be unregistered
 */
export const DynamicModuleLoader = ({ modules, children }) => {
    const store = useStore();
    const [active, setActive] = useState(false);
    useEffect(() => {
        const added = store.addModules(modules);
        setActive(true);
        return () => added.remove();
    }, []);
    return active ? React.createElement(React.Fragment, null, children) : null;
};
//# sourceMappingURL=index.js.map